@@ -10,7 +10,7 @@ use Data::Object::Class;
 
 extends 'Stencil::Source';
 
-our $VERSION = '0.02'; # VERSION
+our $VERSION = '0.03'; # VERSION
 
 1;
 
@@ -67,6 +67,18 @@ specification.
   - from: class-test
     make: t/MyApp.t
 
+  # package functions
+  functions:
+  - name: execute
+    args: "(Str $key) : Any"
+    desc: executes something which triggers something else
+
+  # package methods
+  methods:
+  - name: execute
+    args: "(Str $key) : Any"
+    desc: executes something which triggers something else
+
   # package routines
   routines:
   - name: execute
@@ -120,7 +132,7 @@ L<Issues|https://github.com/iamalnewkirk/stencil/issues>
 =cut
 __DATA__
 
-=spec
+@=spec
 
 name: MyApp
 
@@ -147,7 +159,7 @@ routines:
   args: "(Str $key) : Any"
   desc: executes something which triggers something else
 
-=class
+@=class
 
 package [% data.name %];
 
@@ -198,7 +210,7 @@ sub [% item.name %] {
 
 1;
 
-=class-test
+@=class-test
 
 use 5.014;
 
