@@ -15,7 +15,7 @@ extends 'Stencil::Source';
 
 __DATA__
 
-=spec
+@=spec
 
 name: MyApp
 
@@ -25,7 +25,7 @@ operations:
 - from: class-test
   make: t/MyApp.t
 
-=class
+@=class
 
 package [% data.name %];
 
@@ -36,7 +36,7 @@ use warnings;
 
 1;
 
-=class-test
+@=class-test
 
 use 5.014;
 
